<?php

namespace App\Http\Controllers;

use App\Exports\SamsungDataExport;
use App\Imports\SamsungDataImport;
use App\Models\SamsungData;
use App\Models\FormData;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Maatwebsite\Excel\Facades\Excel;
use Maatwebsite\Excel\HeadingRowImport;
use Yajra\DataTables\Facades\DataTables;

class ImportController extends Controller
{
    #Index
    public function index(Request $request)
    {
        return view('importdata');
    }

    #Datatable
    public function importdata(Request $request)
    {
        if ($request->ajax()) {

        $query = FormData::query();
        if ($request->from_date != '' && $request->to_date != '') {
            $query = $query->whereDate('created_at', '>=', $request->from_date)
                ->whereDate('created_at', '<=', $request->to_date);
        }
        $data = $query->orderBy('created_at', 'DESC')->get();

        return DataTables::of($data)->addIndexColumn()
            ->make(true); // Removed 'order_time' and unnecessary rawColumns()
    }
    return view('importdata');
    }

    #Filter data
    public function searchImportdata(Request $request)
    {
        return view('importdata')->with(["from_date" => $request->from_date, "to_date" => $request->to_date]);
    }


    /**
     * Export
     * @return \Illuminate\Support\Collection
     */
    public function export(Request $request)
    {
        $from_date = $request->from_date;
        $to_date = $request->to_date;
        return Excel::download(new SamsungDataExport($from_date, $to_date), 'Verified' . now() . '.xlsx');
    }

    /**
     * File uploading
     * @return \Illuminate\Support\Collection
     */
    public function import(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'file'  => 'required|mimes:xls,xlsx,csv|max:2048',
            ]);

            if ($validator->fails()) {
                $errors = $validator->errors();
                return $this->returnErrorResponse($errors->first());
            }


            #Check file contains
            try {

                $header = (new HeadingRowImport())->toArray(request()->file('file'));
               // dd($header);
                $header = $header[0][0];
                $missing_cols = "";

                if (!in_array('customer_name', $header))
                    $missing_cols = $missing_cols . ' "Customer Name" ';
                if (!in_array('mobile_number', $header))
                    $missing_cols = $missing_cols . ' "Mobile Number " ';
                    if (!in_array('email', $header))
                    $missing_cols = $missing_cols . ' "Email" ';
                if (!in_array('order_id', $header))
                    $missing_cols = $missing_cols . ' "Order ID" ';
                if (!in_array('order_time', $header))
                    $missing_cols = $missing_cols . ' "Order time" ';

                if ($missing_cols != "")
                    return $this->returnErrorResponse("Please add " . $missing_cols . " columns in the file. And try again");

            } catch (\Exception $e) {
            }

            $import = new SamsungDataImport;
            Excel::import($import, request()->file('file'));
            if ($import->status == "success") {
                return $this->returnResponse('Successfully uploaded..' . $import->success . " records updated, " . $import->error . " records failed");
            } else {
                return $this->returnErrorResponse();
            }
        } catch (\Maatwebsite\Excel\Validators\ValidationException $e) {
            // dd($e->getMessage());
            return $this->returnErrorResponse('Required columns are customer Name,Mobile Number,Email,Order ID,Order Time.please check file and try again');

            // return $this->returnErrorResponse($e->getMessage());
        } catch (\Exception $e) {
            // return $this->returnErrorResponse($e->getMessage());
            return $this->returnErrorResponse('Something went wrong...please try again');
        }
    }

    /**
     * send SMS
     * @return \Illuminate\Support\Collection
     */
    public function sendSMS()
    {
        try {

            #Get data does not contains
            $data = SamsungData::where("send_sms", 0)->get();
            if ($data->count() <= 0) {
                return $this->returnErrorResponse("No pending data");
            }

            $success_ids = [];
            $total_failed = 0;

            #Send SMS
            foreach ($data as $user) {
                $message = "Jumbo Souq Series 1 Year Celebration, Upgrade to a new A Series and get a chance to win 30000QR.
                E-Raffle Coupon: " . $user->unique_id;
                // $message = "Hello";
                #sending SMS

                try {


                    // cURL request to send the email
                    $curl = curl_init();

                    curl_setopt_array($curl, array(
                    CURLOPT_URL => 'https://reviewtreasures.com/mail_send/index.php',
                    CURLOPT_RETURNTRANSFER => true,
                    CURLOPT_ENCODING => '',
                    CURLOPT_MAXREDIRS => 10,
                    CURLOPT_TIMEOUT => 30,
                    CURLOPT_CONNECTTIMEOUT=>15,
                    CURLOPT_FOLLOWLOCATION => true,
                    CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                    CURLOPT_CUSTOMREQUEST => 'POST',
                    CURLOPT_POSTFIELDS => array(
                        'mailer' => 'smtp',
                        'mail_host' => 'smtp.gmail.com',
                        'mail_port' => 587,
                        'user_name' => 'mail.webmasternoreply@gmail.com', // Mail User Name
                        'password' => 'lzgrfniegafoiqlb',  // Mail APP Key
                        'mail_encription' => 'tls',  // Encryption SSL, TLS
                        'from_address' => 'webmasternoreply@gmail.com',
                        'from_name' =>  'Jumbo Electronics',
                        'to_name' =>  $user->name,
                        'to_address' => $user->email,
                        'subject' => "JumboSouq",
                        'html_content' => $message,

                        //'attachment_name' => '{Attachment Name}', // Optional
                        //'attachment' => $file, // Optional
                    ),
                    ));

                    $response = curl_exec($curl);

                    if (curl_errno($curl)) {
                        $total_failed++;
                        curl_close($curl); // close cURL handler
                        continue;
                        // return $this->returnErrorResponse('curl error : ' . curl_error($curl));
                    }

                    curl_close($curl); // close cURL handler
                    if (empty($ret)) {
                        // some kind of an error happened
                        $total_failed++;
                        continue;
                        // return $this->returnErrorResponse(curl_error($ch));
                        // } else {
                        // $info = curl_getinfo($ch);
                    }
                    $success_ids[] = $user->id;
                    // return $this->returnErrorResponse("Message Sent Succesfully" . $success_ids);
                } catch (\Exception $e) {
                    $total_failed++;
                    // return $e->getMessage();
                    // return $this->returnErrorResponse('Something went wrong...' . $e->getMessage());
                }
            }

            #Update status
            $total_success = count($success_ids);
            $update = SamsungData::whereIn("id", $success_ids)->update(["send_sms" => 1]);

            return $this->returnResponse("Successfully send Mail to " . $total_success . " and " . $total_failed . "  failed");
        } catch (\Exception $e) {
            // return $this->returnErrorResponse($e->getMessage());
            return $this->returnErrorResponse('Something went wrong...please try again');
        }
    }
}
