<?php

namespace App\Http\Controllers;

use App\Models\Prize;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class PrizeController extends Controller
{
    //
    /**
     * Add prize details
    */
    public function store(Request $request) 
    {
        try{

            $validator = Validator::make($request->all(), [
                'order_no'  => 'required|unique:prizes,order_no',
                'prize_name'=>'required',
                'prize_value'=>'required'
            ]);
    
            if ($validator->fails()){
                $errors = $validator->errors();
                return $this->returnErrorResponse($errors->first());
            }

            $prize=new Prize();
            $prize->order_no=$request->order_no;
            $prize->prize_name=$request->prize_name;
            $prize->prize_value=$request->prize_value;
            $prize->save();

            if($prize){
                return $this->returnResponse('Prize Added Successfully');
            }

            return $this->returnErrorResponse();

        }catch(\Exception $e){
            // return $this->returnErrorResponse($e->getMessage());
            return $this->returnErrorResponse();
        }
    }

    /**
     * Update prize details
    */
    public function update(Request $request) 
    {
        try{
            $prize_id=$request->prize_id;
            $validator = Validator::make($request->all(), [
                'prize_id' => 'required|exists:prizes,id',
                'order_no'  => 'required|unique:prizes,order_no,'.$prize_id.',id',
                'prize_name'=>'required',
                'prize_value'=>'required'
            ]);
    
            if ($validator->fails()){
                $errors = $validator->errors();
                return $this->returnErrorResponse($errors->first());
            }

            $prize=Prize::where('status',1)->find($prize_id);
            if(!$prize)
                return $this->returnErrorResponse("Prize cannot update");

            $prize->order_no=$request->order_no;
            $prize->prize_name=$request->prize_name;
            $prize->prize_value=$request->prize_value;
            $prize->save();

            if($prize){
                return $this->returnResponse('Prize updated successfully');
            }

            return $this->returnErrorResponse();

        }catch(\Exception $e){
            return $this->returnErrorResponse();
        }
    }

    // View Prize details
    public function show(Request $request) 
    {
        try{
            $validator = Validator::make($request->all(), [
                'prize_id'  => 'required',
            ]);
    
            if ($validator->fails()){
                $errors = $validator->errors();
                return $this->returnErrorResponse($errors->first());
            }

            $prize=Prize::find($request->prize_id);

            if($prize){
                return $this->returnResponse('Prize details',$prize);
            }

            return $this->returnErrorResponse();

        }catch(\Exception $e){
            // return $this->returnErrorResponse($e->getMessage());
            return $this->returnErrorResponse();
        }
    }
    
    // Delete Prize details
    public function delete(Request $request) 
    {
        try{
            $validator = Validator::make($request->all(), [
                'prize_id'  => 'required',
            ]);
    
            if ($validator->fails()){
                $errors = $validator->errors();
                return $this->returnErrorResponse($errors->first());
            }

            $prize=Prize::where('status',1)->find($request->prize_id);
            if(!$prize)
                return $this->returnErrorResponse("Prize cannot delete");

            if($prize->delete()){
                return $this->returnResponse('Prize Deleted Successfully');
            }

            return $this->returnErrorResponse();

        }catch(\Exception $e){
            // return $this->returnErrorResponse($e->getMessage());
            return $this->returnErrorResponse();
        }
    }
}
