<?php

namespace App\Http\Controllers;

use App\Models\Prize;
use App\Models\SamsungData;
use App\Models\Setting;
use App\Models\Winner;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use DB;

class RaffleDrawController extends Controller
{
    #Index
    public function index(Request $request)
    {
        $winners=Winner::get();
        $prizes=Prize::orderby('order_no')->get();
        return view('raffle_draw.index')->with(['winners'=>$winners,'prizes'=>$prizes]);
    }


    /**
     * Winner details
    * @return \Illuminate\Support\Collection
    */
    public function showWinner(Request $request) 
    {
        try{
            $validator = Validator::make($request->all(), [
                'unique_id'  => 'required',
            ]);
    
            if ($validator->fails()){
                $errors = $validator->errors();
                return $this->returnErrorResponse($errors->first());
            }

            $winner=Winner::where('unique_id',$request->unique_id)->first();

            $prize=$winner->prize;
            $winner=$winner->user;

            if($winner){
                return $this->returnResponse('Winner details',["winner"=>$winner,"prize"=>$prize]);
            }

            return $this->returnErrorResponse();

        }catch(\Exception $e){
            return $this->returnErrorResponse($e->getMessage());
            return $this->returnErrorResponse();
        }
    }


    #Raffle Draw
    public function raffleDraw(Request $request)
    {
        $winners=Winner::get();
        $prizes=Prize::orderBy('order_no')->get();
        $next_prize=Prize::where('status',1)->orderBy('order_no')->first();
        $settings=Setting::first();
        $unique_ids=SamsungData::where('status',1)->pluck('unique_id');
        #Shuffle data
        $collection = collect($unique_ids);
        $shuffled = $collection->shuffle();
        $shuffled->all();
        
        return view('raffle_draw.home')->with([
                                            'winners'=>$winners,
                                            'prizes'=>$prizes,
                                            'settings'=>$settings,
                                            'next_prize'=>$next_prize,
                                            'unique_ids'=>$unique_ids
                                        ]);
    }

    #Raffle Draw - save winner
    public function raffleDrawPost(Request $request)
    {
        try{
            
            $validator = Validator::make($request->all(), [
                'prize_id'  => 'required|unique:winners,prize_id',
                'winner'  => 'required|unique:winners,unique_id',
            ]);
    
            if ($validator->fails()){
                $errors = $validator->errors();
                return $this->returnErrorResponse($errors->first());
            }

            $winner_data=SamsungData::where('unique_id',$request->winner)->where('status',1)->first();
            $prize_data=Prize::where('status',1)->find($request->prize_id);
            if(!$winner_data || !$prize_data){
                return $this->returnErrorResponse("Winner is invalid");
            }

            DB::beginTransaction();
            $winner=new Winner();
            $winner->prize_id=$request->prize_id;
            $winner->unique_id=$request->winner;
            $winner->samsung_data_id=$winner_data->id;
            $winner->draw_date=date('Y-m-d H:i:s');
            $winner->save();

            if($winner){
                // Update winner and prize status
                $winner_data->status=0;
                $winner_data->save();
                $prize_data->status=0;
                $prize_data->save();

                DB::commit();

                $unique_ids=SamsungData::where('status',1)->pluck('unique_id');
                #Shuffle data
                $collection = collect($unique_ids);
                $shuffled = $collection->shuffle();
                $shuffled->all();
                
                $next_prize=Prize::where('status',1)->orderBy('order_no')->first();
                return $this->returnResponse('Winner details',[
                    'winner'=>$winner,
                    'winner_details'=>$winner->user,
                    'next_prize'=>$next_prize,
                    'prize'=>$prize_data,
                    'unique_ids'=>$shuffled
                ]);
            }
            DB::rollback();
            return $this->returnErrorResponse();

        }catch(\Exception $e){
            DB::rollback();
            // return $this->returnErrorResponse($e->getMessage());
            return $this->returnErrorResponse();
        }
       
    }

    
    /**
     * send SMS
    * @return \Illuminate\Support\Collection
    */
    public function resetData() 
    {
        try{
            
            #Get data does not contains 
            $update=SamsungData::where("status",0)->update(["status"=>1]);
            $update=Prize::where("status",0)->update(["status"=>1]);
            $update=Winner::query()->truncate();;
            
            return $this->returnResponse("Winners and Price data reset");

        }catch(\Exception $e){
            // return $this->returnErrorResponse($e->getMessage());
            return $this->returnErrorResponse('Something went wrong...please try again');
        }
    }


    // /**
    //  * Export
    // * @return \Illuminate\Support\Collection
    // */
    // public function export(Request $request) 
    // {
    //     $from_date=$request->from_date;
    //     $to_date = $request->to_date;
    //     return Excel::download(new SamsungDataExport($from_date,$to_date), 'Verified'.now().'.xlsx');
    // }

    
}
